library(tidyverse)

# Example - GSS Survey Data - - tvhours
########################################################################################

gss_survey <- read_csv("http://www.cknuckles.com/statsprogramming/data/gss_survey_data.csv")
gss_survey

tvhours_2018 <- gss_survey %>%
  filter(year == "2018") %>%
  select(tvhours) %>%
  drop_na(tvhours)
tvhours_2018

ggplot(data = tvhours_2018, mapping = aes(x = tvhours)) +
  geom_histogram( bins=15, color = "white")

summary(tvhours_2018$tvhours)

tvhours_2018 %>%
  summarize(
    num_couch_potatoes = sum(tvhours >= 3),
    n = n(),
    p_hat = num_couch_potatoes/n   # proportion of couch potatoes
  )


SE <- sqrt((.340*(1-.340))/833)
SE

# 99% CI Multiplier
z_alpha2 <- qnorm(.995, mean=0, sd=1)   # 99% - left tail area .995 = 1 - .005
z_alpha2

# 99% CI for tvhours
c(.340 - z_alpha2*SE, .340 + z_alpha2*SE)


# Example - Political Poll Example
########################################################################################

n <- 1000     # Likely voters polled

phat <- .55   # proportion that supports the Republican candidate.
              # News Report: 55% of 1000 likely voters polled support the candidate.
              # Poll margin of error of approximately ±3%

# The most common confidence level used in polling is 95%

SE <- sqrt((.55*(1-.55))/1000)
SE

# 95% CI Multiplier
z_alpha2 <- qnorm(.975, mean=0, sd=1)   # 95% - left tail area .975 = 1 - .025
z_alpha2

# 95% CI
c(.55 - z_alpha2*SE, .55 + z_alpha2*SE)

poll_margin_of_error <- z_alpha2*SE    # Half of width of the 95% CI
poll_margin_of_error
