library(tidyverse)

# Example - T Distribution
########################################################################################

# n25 sample - Don't know population mu or sigma
xbar <-32.55
s <- 5.36

# T-Distribution Multiplier for 95% CI
t_alpha2 <- qt(.975, df=24)   # left tail area .975 = 1 - .025

# Sampling Distribution Standard Deviation
SE <- s/sqrt(25)

# 95% Confidence Interval - Upper and Lower endpoints stored in a vector
c(xbar - t_alpha2*SE , xbar + t_alpha2*SE)




# Example - GSS Survey Data - workhours
########################################################################################

gss_survey <- read_csv("http://www.cknuckles.com/statsprogramming/data/gss_survey_data.csv")
gss_survey

workhours_2018 <- gss_survey %>%
  filter(year == "2018") %>%
  select(workhours) %>%
  drop_na(workhours)


workhours_2018 %>%
  summarize(
    sample_mean = mean(workhours),
    sample_sd = sd(workhours),
    n = n()
  )

ggplot(data = workhours_2018, mapping = aes(x = workhours)) +
  geom_histogram( bins=30, color = "white")

# 95% CI for the mean `workhours`
t_alpha2 <- qt(.975, df=827)   # left tail area .975 = 1 - .025
SE <- 14.483/sqrt(828)

c(41.530 - t_alpha2*SE, 41.530 + t_alpha2*SE)


# T distribution vs Z distribution Multipliers
########################################################################################

qt(.975, df=99) - qnorm(.975, mean=0, sd=1)

