library(tidyverse)
library(infer) # Contains rep_slice_sample() function

# IMPORTANT
########################################################################################
# This script must have access pre-populated tables from previous scripts:

# The following table from the Bootstrap_Distributions.R script

bootstrap_distribution_of_means

# The following table from the CI_Proportion.R script

tvhours_2018


# Example - Bootstrapped CI for Mean - SE Method
########################################################################################

# n=75 sample dragon wingspans
xbar <- 6.96

bootstrap_stats <- bootstrap_distribution_of_means %>%
  summarize(
    bootstrap_distribution_mean = mean(resample_mean),
    bootstrap_distribution_SE = sd(resample_mean)     # Simulated Estimate for Sampling Dist SE
  )
bootstrap_stats

# 95% CI
SE <-  0.231    # computed above

z_alpha2 <- 1.96   # Assumes bootstrap distribution is normal

c(xbar - z_alpha2*SE, xbar + z_alpha2*SE)


# Example - Bootstrapped CI for Mean - Percentile Method
########################################################################################

# 95% CI - from 2.5th percentile to 97.5th percentile of bootstrap distribution

# 10,000 bootstrap means
boot_dist_means <- bootstrap_distribution_of_means$resample_mean  # from previous script
boot_dist_means

quantile(boot_dist_means, c(.025,.975))



# Example - Bootstrapped CI for Proportion - Percentile Method
########################################################################################

bootstrap_distribution_of_proportions <- tvhours_2018 %>%
  rep_slice_sample(n=833 , reps=10000 ,  replace=TRUE) %>%
  group_by(replicate) %>%
  summarize(
    num_couch_potatoes = sum(tvhours >= 3),
    n = n(),
    resample_proportion = num_couch_potatoes/n   # proportion of couch potatoes
  )
bootstrap_distribution_of_proportions


# Bootstrap Distribution of Proportions
ggplot(bootstrap_distribution_of_proportions, mapping = aes(x = resample_proportion)) +
  geom_histogram(bins=52, color="white") +
  labs(x = "Bootstrap Sample Proportions")


# 10,000 bootstrap means
boot_dist_props <- bootstrap_distribution_of_proportions$resample_proportion  # from previous script
boot_dist_props

# Bootstrap Percentile method 99% CI
quantile(boot_dist_props, c(.005,.995))

