library(tidyverse)
library(infer)

# IMPORTANT
########################################################################################
# This script must have access pre-populated tables from previous scripts:

# The following table from the 03_CI_Mean_T_Dist.R script

workhours_2018

# The following table from the CI_Proportion.R script

tvhours_2018


# Example - Bootstrapped CI for Mean - Using Infer Package
########################################################################################

# Infer package "grammar"
bootstrap_distribution <- workhours_2018 %>%
  specify(response = workhours) %>%
  generate(reps = 10000, type = "bootstrap") %>%
  calculate(stat = "mean")

bootstrap_distribution

# visualize() function from infer package
bootstrap_distribution %>% visualize()

# get_ci() function from infer package
bootstrap_distribution %>%
  get_ci(level=.95, type = "percentile")

bootstrap_distribution %>%
  get_ci(level=.95, type = "se", point_estimate=41.53) #  x_bar for workhours is 41.53

# shade_ci() function from infer package
bootstrap_distribution %>%
  visualize() +                            # Histogram only
  shade_ci(endpoints = c(40.549,42.511))   # Add shaded plot layer for CI



# Example - Bootstrapped CI for Proportion - Using Infer Package
########################################################################################

# Some wrangling needed for Infer package
tvhours_2018_with_potatoes <- tvhours_2018 %>%
  mutate(is_potato = (tvhours>=3))  # new column is_potato = TRUE/FALSE
tvhours_2018_with_potatoes

# For Infer package the specify() response variable must be exactly two-value categorical to define success

# Compute the single-proportion bootstrap distribution
bootstrap_distribution <- tvhours_2018_with_potatoes %>%
  specify(response = is_potato, success = "TRUE") %>%
  generate(reps = 10000, type = "bootstrap") %>%
  calculate(stat = "prop")

# Compute the SE method bootstrap CI
se_ci <- bootstrap_distribution %>%
  get_ci(level=.99, type = "se", point_estimate=.340)
se_ci

# Visualize the results
bootstrap_distribution %>%
  visualize() +
  shade_ci(endpoints = se_ci)


# Example - Bootstrapped CI for Difference of Proportions - Using Infer Package
########################################################################################

# Some wrangling needed for Infer package
gss_survey_2018_wrangled <- gss_survey %>%
  filter(year == "2018") %>%
  drop_na(tvhours,status) %>%
  mutate(is_potato = (tvhours>=3)) %>%
  mutate(married_status = case_when(
    (status == "Married") ~ "married",
    (status != "Married") ~ "single",
  )
  ) %>%
  select(tvhours,is_potato,status,married_status)
gss_survey_2018_wrangled


bootstrap_distribution <- gss_survey_2018_wrangled %>%
  specify(response = is_potato, success = "TRUE", explanatory = married_status) %>%
  generate(reps = 10000, type = "bootstrap") %>%
  calculate(stat = "diff in props", order = c("single","married"))

# Compute percentile method bootstrap CI
ci <- bootstrap_distribution %>%
  get_ci(level=.95, type = "percentile")
ci

# Visualize the results
bootstrap_distribution %>%
  visualize() +
  shade_ci(endpoints = ci)
